@@ -6,7 +6,7 @@ Mojo::Redis2 - Pure-Perl non-blocking I/O Redis driver
 
 =head1 VERSION
 
-0.24
+0.25
 
 =head1 DESCRIPTION
 
@@ -122,6 +122,7 @@ empty string on success.
 
 use Mojo::Base 'Mojo::EventEmitter';
 use Mojo::IOLoop;
+use Mojo::Redis2::Cursor;
 use Mojo::Redis2::Server;
 use Mojo::URL;
 use Mojo::Util;
@@ -129,7 +130,7 @@ use Carp ();
 use constant DEBUG => $ENV{MOJO_REDIS_DEBUG} || 0;
 use constant DEFAULT_PORT => 6379;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 my $PROTOCOL_CLASS = do {
   my $class = $ENV{MOJO_REDIS_PROTOCOL}
@@ -386,6 +387,18 @@ See L<http://redis.io/topics/pubsub> for details.
 The reverse of L</psubscribe>.
 See L<http://redis.io/topics/pubsub> for details.
 
+=head2 scan, hscan, sscan, zscan
+
+  $cur = $self->scan(0, MATCH => 'namesoace*', COUNT => 15);
+  $cur = $self->hscan('hash.key', 0, MATCH => 'pref.*');
+  $cur = $self->sscan('set.key', 0);
+  $cur = $self->zscan('zset.key', 0);
+
+  $res = $cur->next();
+
+Methods from C<SCAN> family will return L<Mojo::Redis2::Cursor> object to
+iterate over elements collection.
+
 =head2 subscribe
 
   $self = $self->subscribe(\@channels, sub { my ($self, $err, $res) = @_; ... });
@@ -607,7 +620,7 @@ MESSAGE:
     if (ref $data eq 'SCALAR') {
       $self->$cb($$data, []) if $cb;
     }
-    elsif (ref $data eq 'ARRAY' and @$data and $data->[0] =~ /^(p?message)$/i) {
+    elsif (ref $data eq 'ARRAY' and $data->[0] and $data->[0] =~ /^(p?message)$/i) {
       $event = shift @$data;
       $self->emit($event => reverse @$data);
     }
@@ -645,11 +658,21 @@ sub _requeue {
   return $self;
 }
 
+sub _scan_operations { qw(scan sscan hscan zscan); }
+
 for my $method (__PACKAGE__->_basic_operations) {
   my $op = uc $method;
   eval "sub $method { shift->_execute(basic => $op => \@_); }; 1" or die $@;
 }
 
+for my $method (__PACKAGE__->_scan_operations) {
+  my $op = uc $method;
+  Mojo::Base::_monkey_patch(__PACKAGE__, $method, sub {
+    my $self = shift;
+    return Mojo::Redis2::Cursor->new(command => [$op => @_])->redis($self);
+  });
+}
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2014, Jan Henning Thorsen
@@ -659,6 +682,8 @@ the terms of the Artistic License version 2.0.
 
 =head1 AUTHOR
 
+Andre Parker
+
 Ben Tyler - C<benjamin.tyler@gmail.com>
 
 Jan Henning Thorsen - C<jhthorsen@cpan.org>
